@@ -3,27 +3,27 @@ use core_foundation_sys::string::CFStringRef;
 use libc::c_void;
 
 #[repr(C)]
-struct OpaqueSecKeychainRef(c_void);
+pub struct OpaqueSecKeychainRef(c_void);
 pub type SecKeychainRef = *mut OpaqueSecKeychainRef;
 
 #[repr(C)]
-struct OpaqueSecKeychainItemRef(c_void);
+pub struct OpaqueSecKeychainItemRef(c_void);
 pub type SecKeychainItemRef = *mut OpaqueSecKeychainItemRef;
 
 #[repr(C)]
-struct OpaqueSecCertificateRef(c_void);
+pub struct OpaqueSecCertificateRef(c_void);
 pub type SecCertificateRef = *mut OpaqueSecCertificateRef;
 
 #[repr(C)]
-struct OpaqueSecAccessRef(c_void);
+pub struct OpaqueSecAccessRef(c_void);
 pub type SecAccessRef = *mut OpaqueSecAccessRef;
 
 #[repr(C)]
-struct OpaqueSecKeyRef(c_void);
+pub struct OpaqueSecKeyRef(c_void);
 pub type SecKeyRef = *mut OpaqueSecKeyRef;
 
 #[repr(C)]
-struct OpaqueSecIdentityRef(c_void);
+pub struct OpaqueSecIdentityRef(c_void);
 pub type SecIdentityRef = *mut OpaqueSecIdentityRef;
 
 pub const errSecSuccess: OSStatus = 0;
