@@ -13,7 +13,7 @@ pub const kSecTrustResultFatalTrustFailure: SecTrustResultType = 6;
 pub const kSecTrustResultOtherError: SecTrustResultType = 7;
 
 #[repr(C)]
-struct __SecTrust(c_void);
+pub struct __SecTrust(c_void);
 
 pub type SecTrustRef = *mut __SecTrust;
 
